@@ -3,14 +3,15 @@ from terraform_compliance.steps.steps import (
     i_have_name_section_configured,
     i_action_them,
     i_expect_the_result_is_operator_than_number,
-    it_condition_contain_something,
+    it_contains_something_old,
     property_is_enabled,
     its_value_condition_match_the_search_regex_regex,
     it_condition_have_proto_protocol_and_port_port_for_cidr,
     it_fails,
     its_key_is_value, its_key_is_not_value,
     its_value_condition_equal,
-    its_value_condition_contain
+    its_value_condition_contain,
+    it_must_contain_something
 )
 from terraform_compliance.common.exceptions import TerraformComplianceNotImplemented, Failure
 from tests.mocks import MockedStep, MockedWorld
@@ -111,7 +112,7 @@ class TestStepCases(TestCase):
         step.context.type = 'resource'
         step.context.stash = ['some_resource']
         with self.assertRaises(Failure):
-            self.assertIsNone(it_condition_contain_something(step, 'something'))
+            self.assertIsNone(it_must_contain_something(step, 'something'))
 
     @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
     @patch('terraform_compliance.common.error_handling.world', side_effect=MockedWorld())
@@ -129,7 +130,7 @@ class TestStepCases(TestCase):
             }
         ]
         with self.assertRaises(Failure) as err:
-            self.assertIsNone(it_condition_contain_something(step, 'something else'))
+            self.assertIsNone(it_must_contain_something(step, 'something else'))
         self.assertEqual(str(err.exception), '{} ({}) does not have {} property.'.format('some_address',
                                                                                          'resource',
                                                                                          'something else'))
@@ -151,7 +152,7 @@ class TestStepCases(TestCase):
             }
         ]
 
-        self.assertIsNone(it_condition_contain_something(step, 'something else'))
+        self.assertIsNone(it_contains_something_old(step, 'something else'))
 
     @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
     def test_it_condition_contain_something_resource_found(self, *args):
@@ -168,7 +169,7 @@ class TestStepCases(TestCase):
             }
         ]
 
-        self.assertTrue(it_condition_contain_something(step, 'something'))
+        self.assertTrue(it_contains_something_old(step, 'something'))
 
     @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
     def test_it_condition_contain_something_resource_value_is_list(self, *args):
@@ -188,9 +189,9 @@ class TestStepCases(TestCase):
             }
         ]
 
-        self.assertTrue(it_condition_contain_something(step, 'something'))
+        self.assertTrue(it_contains_something_old(step, 'something'))
 
-    @patch('terraform_compliance.steps.steps.seek_key_in_dict', return_value=None)
+    @patch('terraform_compliance.steps.then.it_must_contain_something.seek_key_in_dict', return_value=None)
     @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
     @patch('terraform_compliance.common.error_handling.world', side_effect=MockedWorld())
     def test_it_condition_contain_something_provider_not_found(self, *args):
@@ -198,16 +199,16 @@ class TestStepCases(TestCase):
         step.context.type = 'provider'
         step.context.stash = []
 
-        self.assertIsNone(it_condition_contain_something(step, 'something'))
+        self.assertIsNone(it_contains_something_old(step, 'something'))
 
-    @patch('terraform_compliance.steps.steps.seek_key_in_dict', return_value=True)
+    @patch('terraform_compliance.steps.then.it_must_contain_something.seek_key_in_dict', return_value=True)
     @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
     def test_it_condition_contain_something_provider_found(self, *args):
         step = MockedStep()
         step.context.type = 'provider'
         step.context.stash = [{'name': 'test'}]
 
-        self.assertTrue(it_condition_contain_something(step, 'something'))
+        self.assertTrue(it_contains_something_old(step, 'name'))
 
     @patch('terraform_compliance.common.error_handling.world', side_effect=MockedWorld())
     def test_property_is_enabled_not_implemented(self, *args):
@@ -488,6 +489,237 @@ class TestStepCases(TestCase):
         self.assertTrue(type(step.context.stash) is list)
         self.assertEqual(step.context.stash[0]['some_key'], 'some_value[0]')
 
+    def test_its_key_is_value_dict_key_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_two')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 1)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_value')
+
+    def test_its_key_is_value_dict_key_multi_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_one')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 2)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_value')
+        self.assertEqual(step.context.stash[1]['some_key'], 'some_other_value')
+
+    @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
+    def test_its_key_is_value_dict_key_failure(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_four')
+        self.assertEqual(step.state, 'skipped')
+
+    def test_its_key_is_value_dict_kv_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_two', 'tag_value_two')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 1)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_value')
+
+    def test_its_key_is_value_dict_kv_success_2(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one_1',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one_2',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_one', 'tag_value_one_2')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 1)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_other_value')
+
+    def test_its_key_is_value_dict_kv_multi_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_one', 'tag_value_one')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 2)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_value')
+        self.assertEqual(step.context.stash[1]['some_key'], 'some_other_value')
+
+    @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
+    def test_its_key_is_value_dict_kv_failure(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_four', 'whatever')
+        self.assertEqual(step.state, 'skipped')
+
+    @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
+    def test_its_key_is_value_dict_kv_failure_2(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_value(step, 'tags', 'tag_key_three', 'not_tag_key_three')
+        self.assertEqual(step.state, 'skipped')
+
     @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
     def test_find_keys_that_has_kv_structure(self, *args):
         step = MockedStep()
@@ -512,7 +744,7 @@ class TestStepCases(TestCase):
         step.context.name = 'some_name'
         step.context.property_name = 'tags'
         step.context_sensitive_sentence = 'must'
-        it_condition_contain_something(step, 'some_key')
+        it_contains_something_old(step, 'some_key')
         self.assertEqual(step.context.stash[0]['values'], 'some_value')
 
     @patch('terraform_compliance.common.error_handling.world', side_effect=MockedWorld())
@@ -703,6 +935,209 @@ class TestStepCases(TestCase):
         self.assertTrue(type(step.context.stash) is list)
         self.assertEqual(step.context.stash[0]['some_key'], 'some_other_value')
 
+    def test_its_key_is_not_value_dict_key_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_not_value(step, 'tags', 'tag_key_two')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 1)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_other_value')
+
+    def test_its_key_is_not_value_dict_key_case_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_ONE': 'tag_value_one',
+                        'tag_key_TWO': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_ONE': 'tag_value_one',
+                        'tag_key_THREE': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_not_value(step, 'tags', 'tag_key_TWO')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 1)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_other_value')
+
+    def test_its_key_is_not_value_dict_key_multi_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_not_value(step, 'tags', 'tag_key_four')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 2)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_value')
+        self.assertEqual(step.context.stash[1]['some_key'], 'some_other_value')
+
+    @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
+    def test_its_key_is_not_value_dict_key_failure(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_not_value(step, 'tags', 'tag_key_one')
+        self.assertEqual(step.state, 'skipped')
+
+    def test_its_key_is_not_value_dict_kv_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_not_value(step, 'tags', 'tag_key_two', 'tag_value_two')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 1)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_other_value')
+
+    def test_its_key_is_not_value_dict_kv_multi_success(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_not_value(step, 'tags', 'tag_key_two', 'tag_value_three')
+        self.assertTrue(type(step.context.stash) is list)
+        self.assertEqual(len(step.context.stash), 2)
+        self.assertEqual(step.context.stash[0]['some_key'], 'some_value')
+        self.assertEqual(step.context.stash[1]['some_key'], 'some_other_value')
+
+    @patch('terraform_compliance.extensions.ext_radish_bdd.world', return_value=MockedWorld())
+    def test_its_key_is_not_value_dict_kv_failure(self, *args):
+        step = MockedStep()
+        step.context.stash = [
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_two': 'tag_value_two'
+                    }
+                }
+            },
+            {
+                'type': 'aws_db_instance',
+                'some_key': 'some_other_value',
+                'values': {
+                    'tags': {
+                        'tag_key_one': 'tag_value_one',
+                        'tag_key_three': 'tag_value_three'
+                    }
+                }
+            }
+        ]
+        its_key_is_not_value(step, 'tags', 'tag_key_one', 'tag_value_one')
+        self.assertEqual(step.state, 'skipped')
+
     @patch('terraform_compliance.common.error_handling.world', side_effect=MockedWorld())
     def test_its_value_condition_contain(self, *args):
         step = MockedStep()
